/*
 *  AudioFeature Framework
 *	Compute some low-level audio descriptors.
 *  
 *  Marcelo Cicconet, Visgraf / IMPA
 *	www.impa.br/~cicconet
 *
 *	This framework is distributed under the MIT License.
 *	See notice at the end of this file.
 *
 */

#import "AFAuxiliary.h"


@implementation AFAuxiliary

// put in the range [0,1]
+ (void)normalizeUnsignedCurve:(float *)theCurve ofLength:(UInt32)theLength
{
	float maxCurve;
	vDSP_maxv(theCurve, 1, &maxCurve, theLength);
	if (maxCurve > 0.0) {
		for (UInt32 i = 0; i < theLength; i++) {
			theCurve[i] /= maxCurve;
		}
	}
}

// put in the range [-1,1]
+ (void)normalizeSignedCurve:(float *)theCurve ofLength:(UInt32)theLength
{
	float max, min, boxNorm;
	vDSP_maxv(theCurve, 1, &max, theLength);
	vDSP_minv(theCurve, 1, &min, theLength);
	(max > -min ? boxNorm = max : boxNorm = -min);
	if (boxNorm > 0.0) {
		for (UInt32 i = 0; i < theLength; i++) {
			theCurve[i] /= boxNorm;
		}
	}
}

+ (void)putInTheRange01Curve:(float *)theCurve ofLength:(UInt32)theLength
{
	float min, max;
	vDSP_maxv(theCurve, 1, &max, theLength);
	vDSP_minv(theCurve, 1, &min, theLength);
	float range = max-min;
	if (range > 0) {
		for (int i = 0; i < theLength; i++) {
			theCurve[i] = (theCurve[i]-min)/range;
		}
	} else {
		for (int i = 0; i < theLength; i++) {
			theCurve[i] = 0.0;
		}
	}
}

@end

/*
 *	Copyright (C) 2011 by Marcelo Cicconet
 *
 *	Permission is hereby granted, free of charge, to any person obtaining a copy
 *	of this software and associated documentation files (the "Software"), to deal
 *	in the Software without restriction, including without limitation the rights
 *	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *	copies of the Software, and to permit persons to whom the Software is
 *	furnished to do so, subject to the following conditions:
 *
 *	The above copyright notice and this permission notice shall be included in
 *	all copies or substantial portions of the Software.
 *
 *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *	THE SOFTWARE.
 */