/*
 *  AudioFeature Framework
 *	Compute some low-level audio descriptors.
 *  
 *  Marcelo Cicconet, Visgraf / IMPA
 *	www.impa.br/~cicconet
 *
 *	This framework is distributed under the MIT License.
 *	See notice at the end of this file.
 *
 */

#import <Cocoa/Cocoa.h>
#import <vecLib/vDSP.h>
#import "AFAudioDescriptors.h"
#import "AFFloatsMatrix.h"
#import "AFAuxiliary.h"

@interface AFFeaturesMatrix : NSObject {
	UInt32 windowSize;
	UInt32 halfWindowSize;
	UInt32 hopSize;
	UInt32 numWindows;
	AFAudioDescriptors * audioDescriptors;
}

@property(readonly) UInt32 numWindows;

- (id)initWithWindowSize:(UInt32)theWindowSize andHopSize:(UInt32)theHopSize forAudioLength:(UInt32)theAudioLength;

// 1-dimensional (not normalized)
- (void)spectralFlux:(float *)theSpectralFlux ofAudioSignal:(float *)theAudioSignal;
- (void)loudness:(float *)theLoudness ofAudioSignal:(float *)theAudioSignal;
- (void)spectralCentroid:(float *)theSpectralCentroid ofAudioSignal:(float *)theAudioSignal;
- (void)spectralSpread:(float *)theSpectralSpread ofAudioSignal:(float *)theAudioSignal;
- (void)spectralSkewness:(float *)theSpectralSkewness ofAudioSignal:(float *)theAudioSignal;
- (void)spectralRollOff:(float *)theSpectralRollOff ofAudioSignal:(float *)theAudioSignal;
- (void)spectralFlatness:(float *)theSpectralFlatness ofAudioSignal:(float *)theAudioSignal;
- (void)spectralCrest:(float *)theSpectralCrest ofAudioSignal:(float *)theAudioSignal;
// N-dimensional (normalized)
- (void)preChromagram:(AFFloatsMatrix *)thePreChromagram ofAudioSignal:(float *)theAudioSignal;
- (void)chromagram:(AFFloatsMatrix *)theChromagram ofAudioSignal:(float *)theAudioSignal;
- (void)barkBands:(AFFloatsMatrix *)theBarkBands ofAudioSignal:(float *)theAudioSignal;
- (void)chromaAndLoudness:(AFFloatsMatrix *)theChromaAndLoudness ofAudioSignal:(float *)theAudioSignal;

- (void)dealloc;

@end

/*
 *	Copyright (C) 2011 by Marcelo Cicconet
 *
 *	Permission is hereby granted, free of charge, to any person obtaining a copy
 *	of this software and associated documentation files (the "Software"), to deal
 *	in the Software without restriction, including without limitation the rights
 *	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *	copies of the Software, and to permit persons to whom the Software is
 *	furnished to do so, subject to the following conditions:
 *
 *	The above copyright notice and this permission notice shall be included in
 *	all copies or substantial portions of the Software.
 *
 *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *	THE SOFTWARE.
 */