/*
 *  AudioFeature Framework
 *	Compute some low-level audio descriptors.
 *  
 *  Marcelo Cicconet, Visgraf / IMPA
 *	www.impa.br/~cicconet
 *
 *	This framework is distributed under the MIT License.
 *	See notice at the end of this file.
 *
 */

#import "AFFloatsMatrix.h"


@implementation AFFloatsMatrix

- (id)initWithRowsCount:(UInt32)theRowsCount andColsCount:(UInt32)theColsCount
{
	if ((self = [super init])) {
		nRows = theRowsCount;
		nCols = theColsCount;
		entries = (float *)calloc(nRows*nCols, sizeof(float));
	}
	return self;
}

- (void)setValue:(float)theValue forRow:(UInt32)theRow andCol:(UInt32)theCol
{
	// fill the matrix row per row
	entries[nCols*theRow+theCol] = theValue;
}

- (float)valueAtRow:(UInt32)theRow andCol:(UInt32)theCol
{
	// get values row per row
	return entries[nCols*theRow+theCol];
}

- (void)alongColumnsSum:(float *)theSum
{
	float accumulator;
	for (UInt32 col = 0; col < nCols; col++) {
		accumulator = 0.0;
		for (UInt32 row = 0; row < nRows; row++) {
			accumulator += [self valueAtRow:row andCol:col];
		}
		theSum[col] = accumulator;
	}
}

- (void)alongColumnsMean:(float *)theMean
{
	float accumulator;
	for (UInt32 col = 0; col < nCols; col++) {
		accumulator = 0.0;
		for (UInt32 row = 0; row < nRows; row++) {
			accumulator += [self valueAtRow:row andCol:col];
		}
		theMean[col] = accumulator/(float)nRows;
	}	
}

- (void)dealloc
{
	free(entries);
	[super dealloc];
}

@end

/*
 *	Copyright (C) 2011 by Marcelo Cicconet
 *
 *	Permission is hereby granted, free of charge, to any person obtaining a copy
 *	of this software and associated documentation files (the "Software"), to deal
 *	in the Software without restriction, including without limitation the rights
 *	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *	copies of the Software, and to permit persons to whom the Software is
 *	furnished to do so, subject to the following conditions:
 *
 *	The above copyright notice and this permission notice shall be included in
 *	all copies or substantial portions of the Software.
 *
 *	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *	OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *	THE SOFTWARE.
 */